==> nifi-2.0.0-source-release.zip: nifi-2.0.0/nifi-frontend/src/main/frontend/apps/nifi/src/app/pages/documentation/state/documentation/documentation.effects.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { Injectable } from '@angular/core';
import { Actions, createEffect, ofType } from '@ngrx/effects';
import * as DocumentationActions from './documentation.actions';
import { tap } from 'rxjs';
import { Router } from '@angular/router';

@Injectable()
export class DocumentationEffects {
    constructor(
        private actions$: Actions,
        private router: Router
    ) {}

    navigateToOverview$ = createEffect(
        () =>
            this.actions$.pipe(
                ofType(DocumentationActions.navigateToOverview),
                tap(() => {
                    this.router.navigate(['/documentation', 'overview']);
                })
            ),
        { dispatch: false }
    );
}

==> nifi-2.7.2-source-release.zip: nifi-2.7.2/nifi-frontend/src/main/frontend/apps/nifi/src/app/pages/documentation/state/documentation/documentation.effects.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { Injectable, inject } from '@angular/core';
import { Actions, createEffect, ofType } from '@ngrx/effects';
import * as DocumentationActions from './documentation.actions';
import { tap } from 'rxjs';
import { Router } from '@angular/router';

@Injectable()
export class DocumentationEffects {
    private actions$ = inject(Actions);
    private router = inject(Router);

    navigateToOverview$ = createEffect(
        () =>
            this.actions$.pipe(
                ofType(DocumentationActions.navigateToOverview),
                tap(() => {
                    this.router.navigate(['/documentation', 'overview']);
                })
            ),
        { dispatch: false }
    );
}
